Fix and enhance some tests.
diff --git a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/AllTests.java b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/AllTests.java
index 1d658fe..54082bf 100644
--- a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/AllTests.java
+++ b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/AllTests.java
@@ -24,7 +24,7 @@
 	SWTBotFormTextTest.class,
 	SWTBotHyperlinkTest.class,
 	SWTBotImageHyperlinkTest.class,
-	SWTBotScrolledFormTextTest.class,
+	SWTBotScrolledFormTest.class,
 	SWTBotSectionTest.class,
 	SWTBotTreeNodeTest.class,
 	SWTBotTwistieTest.class
diff --git a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/AbstractSWTBotFormsTest.java b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/AbstractSWTBotFormsTest.java
index 5bbc0ff..4031393 100644
--- a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/AbstractSWTBotFormsTest.java
+++ b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/AbstractSWTBotFormsTest.java
@@ -10,12 +10,21 @@
  *******************************************************************************/

 package org.eclipse.swtbot.forms.finder.test.widgets;

 

+import static org.eclipse.swtbot.swt.finder.finders.UIThreadRunnable.syncExec;

+

 import java.util.List;

 

 import org.eclipse.swtbot.eclipse.finder.SWTWorkbenchBot;

+import org.eclipse.swtbot.eclipse.finder.finders.WorkbenchContentsFinder;

 import org.eclipse.swtbot.eclipse.finder.widgets.SWTBotEditor;

+import org.eclipse.swtbot.eclipse.finder.widgets.SWTBotView;

 import org.eclipse.swtbot.forms.finder.finders.SWTFormsBot;

 import org.eclipse.swtbot.swt.finder.exceptions.WidgetNotFoundException;

+import org.eclipse.swtbot.swt.finder.results.VoidResult;

+import org.eclipse.swtbot.swt.finder.utils.SWTBotPreferences;

+import org.eclipse.ui.IWorkbenchWindow;

+import org.eclipse.ui.PartInitException;

+import org.eclipse.ui.actions.ActionFactory;

 import org.junit.After;

 import org.junit.BeforeClass;

 

@@ -27,16 +36,40 @@
 	@BeforeClass

 	public static void beforeClass() {

 		closeWelcomePage();

+		closeAllViews();

+		showFormsView();

+	}

+

+	private static void showFormsView() {

+		syncExec(new VoidResult() {

+			public void run() {

+				IWorkbenchWindow window = new WorkbenchContentsFinder().activeWorkbenchWindow();

+				try {

+					window.getActivePage().showView("org.eclipse.ui.forms.examples.views.FormView");

+					ActionFactory.MAXIMIZE.create(window).run();

+				} catch (PartInitException e) {

+					throw new RuntimeException(e);

+				}

+			}

+		});

+	}

+

+	private static void closeAllViews() {

+		List<SWTBotView> views = workbench.views();

+		for (SWTBotView view : views) {

+			view.close();

+		}

 	}

 

 	private static void closeWelcomePage() {

 		try {

+			SWTBotPreferences.TIMEOUT = 0;

 			System.setProperty("org.eclipse.swtbot.search.timeout", "0");

 			workbench.viewByTitle("Welcome").close();

 		} catch (WidgetNotFoundException e) {

 			// do nothing

 		} finally {

-			System.setProperty("org.eclipse.swtbot.search.timeout", "5000");

+			SWTBotPreferences.TIMEOUT = 5000;

 		}

 	}

 

diff --git a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotExpandableCompositeTest.java b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotExpandableCompositeTest.java
index 6d734ca..d808c6b 100644
--- a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotExpandableCompositeTest.java
+++ b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotExpandableCompositeTest.java
@@ -15,6 +15,7 @@
 
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotExpandableComposite;
 import org.eclipse.swtbot.swt.finder.junit.SWTBotJunit4ClassRunner;
+import org.eclipse.ui.forms.widgets.ExpandableComposite;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
@@ -27,6 +28,7 @@
 		SWTBotExpandableComposite composite = bot.expandableComposite(title);
 		assertNotNull(composite);
 		assertEquals(title, composite.getText());
+		assertEquals(ExpandableComposite.class, composite.widget.getClass());
 	}
 	
 }
diff --git a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotFormTextTest.java b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotFormTextTest.java
index a2f3e28..64131e9 100644
--- a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotFormTextTest.java
+++ b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotFormTextTest.java
@@ -13,11 +13,13 @@
 import static org.junit.Assert.assertNotNull;
 
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotFormText;
+import org.junit.Ignore;
 import org.junit.Test;
 
 public class SWTBotFormTextTest extends AbstractSWTBotFormsTest {
 
 	@Test
+	@Ignore("Need to figure out a way to get text back.")
 	public void findsFormText() throws Exception {
 		StringBuffer buf = new StringBuffer();
 		buf.append("<form>");
diff --git a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotHyperlinkTest.java b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotHyperlinkTest.java
index 1c193a9..78f0801 100644
--- a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotHyperlinkTest.java
+++ b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotHyperlinkTest.java
@@ -10,19 +10,33 @@
  *******************************************************************************/
 package org.eclipse.swtbot.forms.finder.test.widgets;
 
+import static org.eclipse.swtbot.swt.finder.SWTBotAssert.assertMatchesRegex;
+import static org.eclipse.swtbot.swt.finder.matchers.WidgetMatcherFactory.withRegex;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotHyperlink;
+import org.eclipse.ui.forms.widgets.Hyperlink;
 import org.junit.Test;
 
 public class SWTBotHyperlinkTest extends AbstractSWTBotFormsTest {
 
 	@Test
 	public void findHyperlink() throws Exception {
-		SWTBotHyperlink link = bot.hyperlink();
+		String text = "This is an example of a form that is much longer and will need to wrap.";
+		SWTBotHyperlink link = bot.hyperlink(text);
 		assertNotNull(link);
-		assertEquals("This is an example of a form that is much longer and will need to wrap.", link.getText());
+		assertEquals(text, link.getText());
+		assertEquals(Hyperlink.class, link.widget.getClass());
 	}
-	
+
+	@Test
+	public void canFindHyperlinkWithRegex() throws Exception {
+		String text = "example of a form .* is much longer";
+		SWTBotHyperlink link = new SWTBotHyperlink((Hyperlink) bot.widget(withRegex(text)));
+		assertNotNull(link);
+		assertMatchesRegex(text, link.getText());
+		assertEquals(Hyperlink.class, link.widget.getClass());
+	}
+
 }
diff --git a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotImageHyperlinkTest.java b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotImageHyperlinkTest.java
index bff520b..62d1cc8 100644
--- a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotImageHyperlinkTest.java
+++ b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotImageHyperlinkTest.java
@@ -10,19 +10,52 @@
  *******************************************************************************/
 package org.eclipse.swtbot.forms.finder.test.widgets;
 
+import static org.eclipse.swtbot.swt.finder.matchers.WidgetMatcherFactory.withRegex;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotImageHyperlink;
+import org.eclipse.ui.forms.widgets.ImageHyperlink;
 import org.junit.Test;
 
 public class SWTBotImageHyperlinkTest extends AbstractSWTBotFormsTest {
 
 	@Test
-	public void findImageHyperlink() throws Exception {
-		SWTBotImageHyperlink link = bot.imageHyperlink("Image link with no image");
+	public void findImageHyperlinkWithNoImage() throws Exception {
+		String text = "Image link with no image";
+		SWTBotImageHyperlink link = bot.imageHyperlink(text);
 		assertNotNull(link);
-		assertEquals("Image link with no image", link.getText());
+		assertEquals(text, link.getText());
+		assertEquals(ImageHyperlink.class, link.widget.getClass());
 	}
 	
+	@Test
+	public void canFindImageHyperlinkWithNoImageByRegex() throws Exception {
+		String text = "link with no";
+		SWTBotImageHyperlink link = new SWTBotImageHyperlink((ImageHyperlink) bot.widget(withRegex(text)));
+
+		assertNotNull(link);
+		assertEquals("Image link with no image", link.getText());
+		assertEquals(ImageHyperlink.class, link.widget.getClass());
+	}
+	
+	
+	@Test
+	public void findImageHyperlinkWithImage() throws Exception {
+		String text = "Link with image and text";
+		SWTBotImageHyperlink link = bot.imageHyperlink(text);
+		assertNotNull(link);
+		assertEquals(text, link.getText());
+		assertEquals(ImageHyperlink.class, link.widget.getClass());
+	}
+	
+	@Test
+	public void canFindImageHyperlinkWithImageByRegex() throws Exception {
+		String text = "with image";
+		SWTBotImageHyperlink link = new SWTBotImageHyperlink((ImageHyperlink) bot.widget(withRegex(text)));
+
+		assertNotNull(link);
+		assertEquals("Link with image and text", link.getText());
+		assertEquals(ImageHyperlink.class, link.widget.getClass());
+	}
 }
diff --git a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotScrolledFormTest.java b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotScrolledFormTest.java
new file mode 100644
index 0000000..63ef419
--- /dev/null
+++ b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotScrolledFormTest.java
@@ -0,0 +1,44 @@
+/*******************************************************************************
+ * Copyright (c) 2010 Chris Aniszczyk and others.
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ * 
+ * Contributors:
+ *     Chris Aniszczyk <caniszczyk@gmail.com> - initial API and implementation
+ *******************************************************************************/
+package org.eclipse.swtbot.forms.finder.test.widgets;
+
+import static org.eclipse.swtbot.swt.finder.matchers.WidgetMatcherFactory.allOf;
+import static org.eclipse.swtbot.swt.finder.matchers.WidgetMatcherFactory.widgetOfType;
+import static org.eclipse.swtbot.swt.finder.matchers.WidgetMatcherFactory.withRegex;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
+import org.eclipse.swt.widgets.Widget;
+import org.eclipse.swtbot.forms.finder.widgets.SWTBotScrolledForm;
+import org.eclipse.ui.forms.widgets.ScrolledForm;
+import org.junit.Test;
+
+public class SWTBotScrolledFormTest extends AbstractSWTBotFormsTest {
+
+	@Test
+	public void findsScrolledFormText() throws Exception {
+		String title = "Hello, Eclipse Forms";
+		SWTBotScrolledForm text = bot.scrolledForm();
+		assertNotNull(text);
+		assertEquals(title, text.getText());
+		assertEquals(ScrolledForm.class, text.widget.getClass());
+	}
+
+	@Test
+	public void findsScrolledFormTextByRegex() throws Exception {
+		String regex = "Hello, [Ee]clip.. Forms";
+		Widget widget = bot.widget(allOf(widgetOfType(ScrolledForm.class), withRegex(regex)));
+		SWTBotScrolledForm text = new SWTBotScrolledForm((ScrolledForm) widget);
+		assertNotNull(text);
+		assertEquals("Hello, Eclipse Forms", text.getText());
+		assertEquals(ScrolledForm.class, text.widget.getClass());
+	}
+}
diff --git a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotScrolledFormTextTest.java b/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotScrolledFormTextTest.java
deleted file mode 100644
index 2f79672..0000000
--- a/org.eclipse.swtbot.forms.finder.test/src/org/eclipse/swtbot/forms/finder/test/widgets/SWTBotScrolledFormTextTest.java
+++ /dev/null
@@ -1,29 +0,0 @@
-/*******************************************************************************
- * Copyright (c) 2010 Chris Aniszczyk and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- * 
- * Contributors:
- *     Chris Aniszczyk <caniszczyk@gmail.com> - initial API and implementation
- *******************************************************************************/
-package org.eclipse.swtbot.forms.finder.test.widgets;
-
-import static org.junit.Assert.assertNotNull;
-
-import org.eclipse.swtbot.forms.finder.widgets.SWTBotScrolledFormText;
-import org.junit.Test;
-
-public class SWTBotScrolledFormTextTest extends AbstractSWTBotFormsTest {
-
-	@Test
-	public void findsScrolledFormText() throws Exception {
-		String title = "Hello, Eclipse Forms";
-		SWTBotScrolledFormText text = bot.scrolledFormText();
-		assertNotNull(text);
-		text.setFocus();
-		System.out.println(text.widget.getFormText().getSelectionText());
-	}
-	
-}
diff --git a/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/widgets/SWTBotScrolledForm.java b/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/widgets/SWTBotScrolledForm.java
new file mode 100644
index 0000000..306069e
--- /dev/null
+++ b/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/widgets/SWTBotScrolledForm.java
@@ -0,0 +1,50 @@
+/*******************************************************************************
+ * Copyright (c) 2010 Chris Aniszczyk and others.
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ * 
+ * Contributors:
+ *     Chris Aniszczyk <caniszczyk@gmail.com> - initial API and implementation
+ *******************************************************************************/
+package org.eclipse.swtbot.forms.finder.widgets;
+
+import org.eclipse.swtbot.swt.finder.ReferenceBy;
+import org.eclipse.swtbot.swt.finder.SWTBotWidget;
+import org.eclipse.swtbot.swt.finder.exceptions.WidgetNotFoundException;
+import org.eclipse.swtbot.swt.finder.widgets.AbstractSWTBotControl;
+import org.eclipse.ui.forms.widgets.ScrolledForm;
+import org.hamcrest.SelfDescribing;
+
+/**
+ * This represents a {@link ScrolledForm} widget.
+ * 
+ * @author Chris Aniszczyk &lt;caniszczyk [at] gmail [dot] com&gt;
+ * @version $Id$
+ */
+@SWTBotWidget(clasz = ScrolledForm.class, preferredName = "scrolledFormText", referenceBy = { ReferenceBy.TEXT })
+public class SWTBotScrolledForm extends AbstractSWTBotControl<ScrolledForm> {
+
+	/**
+	 * Constructs a new instance with the given widget.
+	 * 
+	 * @param w the widget.
+	 * @throws WidgetNotFoundException if the widget is <code>null</code> or widget has been disposed.
+	 */
+	public SWTBotScrolledForm(ScrolledForm w) throws WidgetNotFoundException {
+		super(w);
+	}
+
+	/**
+	 * Constructs a new instance with the given widget.
+	 * 
+	 * @param w the widget.
+	 * @param description the description of the widget, this will be reported by {@link #toString()}
+	 * @throws WidgetNotFoundException if the widget is <code>null</code> or widget has been disposed.
+	 */
+	public SWTBotScrolledForm(ScrolledForm w, SelfDescribing description) throws WidgetNotFoundException {
+		super(w, description);
+	}
+
+}
diff --git a/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/widgets/SWTBotScrolledFormText.java b/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/widgets/SWTBotScrolledFormText.java
deleted file mode 100644
index db1fe7e..0000000
--- a/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/widgets/SWTBotScrolledFormText.java
+++ /dev/null
@@ -1,76 +0,0 @@
-/*******************************************************************************
- * Copyright (c) 2010 Chris Aniszczyk and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- * 
- * Contributors:
- *     Chris Aniszczyk <caniszczyk@gmail.com> - initial API and implementation
- *******************************************************************************/
-package org.eclipse.swtbot.forms.finder.widgets;
-
-import org.eclipse.swtbot.swt.finder.ReferenceBy;
-import org.eclipse.swtbot.swt.finder.SWTBotWidget;
-import org.eclipse.swtbot.swt.finder.exceptions.WidgetNotFoundException;
-import org.eclipse.swtbot.swt.finder.results.StringResult;
-import org.eclipse.swtbot.swt.finder.results.VoidResult;
-import org.eclipse.swtbot.swt.finder.widgets.AbstractSWTBotControl;
-import org.eclipse.ui.forms.widgets.ScrolledFormText;
-import org.hamcrest.SelfDescribing;
-
-/**
- * This represents a {@link ScrolledFormText} widget.
- * 
- * @author Chris Aniszczyk &lt;caniszczyk [at] gmail [dot] com&gt;
- * @version $Id$
- */
-@SWTBotWidget(clasz = ScrolledFormText.class, preferredName = "scrolledFormText", referenceBy = { ReferenceBy.TEXT })
-public class SWTBotScrolledFormText extends AbstractSWTBotControl<ScrolledFormText> {
-
-	/**
-	 * Constructs a new instance with the given widget.
-	 * 
-	 * @param w the widget.
-	 * @throws WidgetNotFoundException if the widget is <code>null</code> or widget has been disposed.
-	 */
-	public SWTBotScrolledFormText(ScrolledFormText w) throws WidgetNotFoundException {
-		super(w);
-	}
-
-	/**
-	 * Constructs a new instance with the given widget.
-	 * 
-	 * @param w the widget.
-	 * @param description the description of the widget, this will be reported by {@link #toString()}
-	 * @throws WidgetNotFoundException if the widget is <code>null</code> or widget has been disposed.
-	 */
-	public SWTBotScrolledFormText(ScrolledFormText w, SelfDescribing description) throws WidgetNotFoundException {
-		super(w, description);
-	}
-	
-	public String selectionText() {
-		return syncExec(new StringResult() {
-			public String run() {
-				return widget.getFormText().getSelectionText();
-			}
-		});
-	}
-	
-	public String selectedLinkText() {
-		return syncExec(new StringResult() {
-			public String run() {
-				return widget.getFormText().getSelectedLinkText();
-			}
-		});
-	}
-	
-	public void setText(final String text, final boolean parseTags, final boolean expandURLs) {
-		syncExec(new VoidResult() {
-			public void run() {
-				widget.getFormText().setText(text, parseTags, expandURLs);
-			}
-		});
-	}
-
-}
diff --git a/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/finders/SWTFormsBot.java b/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/finders/SWTFormsBot.java
index ab2c0b0..4d35d4b 100644
--- a/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/finders/SWTFormsBot.java
+++ b/org.eclipse.swtbot.forms.finder/src/org/eclipse/swtbot/forms/finder/finders/SWTFormsBot.java
@@ -20,7 +20,7 @@
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotFormText;
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotHyperlink;
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotImageHyperlink;
-import org.eclipse.swtbot.forms.finder.widgets.SWTBotScrolledFormText;
+import org.eclipse.swtbot.forms.finder.widgets.SWTBotScrolledForm;
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotSection;
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotTreeNode;
 import org.eclipse.swtbot.forms.finder.widgets.SWTBotTwistie;
@@ -32,7 +32,7 @@
 import org.eclipse.ui.forms.widgets.FormText;
 import org.eclipse.ui.forms.widgets.Hyperlink;
 import org.eclipse.ui.forms.widgets.ImageHyperlink;
-import org.eclipse.ui.forms.widgets.ScrolledFormText;
+import org.eclipse.ui.forms.widgets.ScrolledForm;
 import org.eclipse.ui.forms.widgets.Section;
 import org.eclipse.ui.forms.widgets.TreeNode;
 import org.eclipse.ui.forms.widgets.Twistie;
@@ -380,51 +380,51 @@
 	}
 	
 	/**
-	 * @return a {@link SWTBotScrolledFormText}.
+	 * @return a {@link SWTBotScrolledForm}.
 	 */
-	public SWTBotScrolledFormText scrolledFormText() {
-		Matcher matcher = allOf(widgetOfType(ScrolledFormText.class));
-		return new SWTBotScrolledFormText((ScrolledFormText) widget(matcher, 0), matcher);
+	public SWTBotScrolledForm scrolledForm() {
+		Matcher matcher = allOf(widgetOfType(ScrolledForm.class));
+		return new SWTBotScrolledForm((ScrolledForm) widget(matcher, 0), matcher);
 	}
 	
 	/**
 	 * @param key the key set on the widget.
 	 * @param value the value for the key.
 	 * @return a {@link SWTBotScrolledFormText} with the specified <code>key/value</code>.
 	 */
-	public SWTBotScrolledFormText scrolledFormTextWithId(String key, String value) {
-		return scrolledFormTextWithId(key, value, 0);
+	public SWTBotScrolledForm scrolledFormWithId(String key, String value) {
+		return scrolledFormWithId(key, value, 0);
 	}
 
 	/**
 	 * @param key the key set on the widget.
 	 * @param value the value for the key.
 	 * @param index the index of the widget.
 	 * @return a {@link SWTBotScrolledFormText} with the specified <code>key/value</code>.
 	 */
 	@SuppressWarnings("unchecked")
-	public SWTBotScrolledFormText scrolledFormTextWithId(String key, String value, int index) {
-		Matcher matcher = allOf(widgetOfType(ScrolledFormText.class), withId(key, value));
-		return new SWTBotScrolledFormText((ScrolledFormText) widget(matcher, index), matcher);
+	public SWTBotScrolledForm scrolledFormWithId(String key, String value, int index) {
+		Matcher matcher = allOf(widgetOfType(ScrolledForm.class), withId(key, value));
+		return new SWTBotScrolledForm((ScrolledForm) widget(matcher, index), matcher);
 	}
 
 	/**
 	 * @param value the value for the key {@link org.eclipse.swtbot.swt.finder.utils.SWTBotPreferences#DEFAULT_KEY}.
 	 * @return a {@link SWTBotScrolledFormText} with the specified <code>value</code>.
 	 */
-	public SWTBotScrolledFormText scrolledFormTextWithId(String value) {
-		return scrolledFormTextWithId(value, 0);
+	public SWTBotScrolledForm scrolledFormWithId(String value) {
+		return scrolledFormWithId(value, 0);
 	}
 
 	/**
 	 * @param value the value for the key {@link org.eclipse.swtbot.swt.finder.utils.SWTBotPreferences#DEFAULT_KEY}.
 	 * @param index the index of the widget.
 	 * @return a {@link SWTBotScrolledFormText} with the specified <code>value</code>.
 	 */
 	@SuppressWarnings("unchecked")
-	public SWTBotScrolledFormText scrolledFormTextWithId(String value, int index) {
-		Matcher matcher = allOf(widgetOfType(ScrolledFormText.class), withId(value));
-		return new SWTBotScrolledFormText((ScrolledFormText) widget(matcher, index), matcher);
+	public SWTBotScrolledForm scrolledFormWithId(String value, int index) {
+		Matcher matcher = allOf(widgetOfType(ScrolledForm.class), withId(value));
+		return new SWTBotScrolledForm((ScrolledForm) widget(matcher, index), matcher);
 	}
 	
 	/**
@@ -380,51 +380,51 @@
 	 * @param key the key set on the widget.
 	 * @param value the value for the key.
-	 * @return a {@link SWTBotScrolledFormText} with the specified <code>key/value</code>.
+	 * @return a {@link SWTBotScrolledForm} with the specified <code>key/value</code>.
 	 */
@@ -380,51 +380,51 @@
 	 * @param value the value for the key.
 	 * @param index the index of the widget.
-	 * @return a {@link SWTBotScrolledFormText} with the specified <code>key/value</code>.
+	 * @return a {@link SWTBotScrolledForm} with the specified <code>key/value</code>.
 	 */
 	@SuppressWarnings("unchecked")
@@ -380,51 +380,51 @@
 	/**
 	 * @param value the value for the key {@link org.eclipse.swtbot.swt.finder.utils.SWTBotPreferences#DEFAULT_KEY}.
-	 * @return a {@link SWTBotScrolledFormText} with the specified <code>value</code>.
+	 * @return a {@link SWTBotScrolledForm} with the specified <code>value</code>.
 	 */
@@ -380,51 +380,51 @@
 	 * @param value the value for the key {@link org.eclipse.swtbot.swt.finder.utils.SWTBotPreferences#DEFAULT_KEY}.
 	 * @param index the index of the widget.
-	 * @return a {@link SWTBotScrolledFormText} with the specified <code>value</code>.
+	 * @return a {@link SWTBotScrolledForm} with the specified <code>value</code>.
 	 */
 	@SuppressWarnings("unchecked")